@@ -270,131 +270,6 @@ class TokenReader:
                 token=token,
             ) from e
 
-    # noinspection PyMethodMayBeStatic
-    async def get_jwks_uri_async(
-        self, *, well_known_config: Dict[str, Any]
-    ) -> str | None:
-        """
-        Retrieves the JWKS URI and issuer from the well-known OpenID Connect configuration.
-        Returns:
-            tuple: (jwks_uri, issuer)
-        Raises:
-            ValueError: If required fields are missing.
-        """
-        jwks_uri: str | None = well_known_config.get("jwks_uri")
-        issuer = well_known_config.get("issuer")
-        if not jwks_uri:
-            raise ValueError(
-                f"jwks_uri not found in well-known configuration: {well_known_config}"
-            )
-        if not issuer:
-            raise ValueError(
-                f"issuer not found in well-known configuration: {well_known_config}"
-            )
-        return jwks_uri
-
-    async def get_subject_from_token_async(self, *, token: str) -> Optional[str]:
-        """
-        Extracts the 'sub' (subject) claim from the JWT token.
-        Args:
-            token (str): The JWT token string.
-        Returns:
-            Optional[str]: The subject claim if present, otherwise None.
-        """
-        if not token:
-            raise ValueError("Token must not be empty")
-        jwks: KeySet = await self._well_known_config_manager.get_jwks_async()
-        try:
-            claims = jwt.decode(token, jwks, algorithms=self.algorithms).claims
-            return claims.get("email") or claims.get("sub")
-        except Exception as e:
-            logger.exception(f"Failed to extract subject from token: {e}")
-            return None
-
-    async def get_expires_from_token_async(
-        self, token: str
-    ) -> Optional[datetime.datetime]:
-        """
-        Extracts the 'exp' (expiration) claim from the JWT token.
-        Args:
-            token (str): The JWT token string.
-        Returns:
-            Optional[datetime.datetime]: The expiration time as a datetime object if present, otherwise None.
-        """
-        if not token:
-            raise ValueError("Token must not be empty")
-        jwks: KeySet = await self._well_known_config_manager.get_jwks_async()
-        try:
-            claims = jwt.decode(token, jwks, algorithms=self.algorithms).claims
-            exp = claims.get("exp")
-            if exp:
-                return datetime.datetime.fromtimestamp(exp, tz=ZoneInfo("UTC"))
-            return None
-        except Exception as e:
-            logger.exception(f"Failed to extract expiration from token: {e}")
-            return None
-
-    async def get_issuer_from_token_async(self, token: str) -> Optional[str]:
-        """
-        Extracts the 'iss' (issuer) claim from the JWT token.
-        Args:
-            token (str): The JWT token string.
-        Returns:
-            Optional[str]: The issuer claim if present, otherwise None.
-        """
-        if not token:
-            raise ValueError("Token must not be empty")
-        jwks: KeySet = await self._well_known_config_manager.get_jwks_async()
-        try:
-            claims = jwt.decode(token, jwks, algorithms=self.algorithms).claims
-            return claims.get("iss")
-        except Exception as e:
-            logger.exception(f"Failed to extract issuer from token: {e}")
-            return None
-
-    async def get_audience_from_token_async(self, token: str) -> Optional[str]:
-        """
-        Extracts the 'aud' (audience) claim from the JWT token.
-        Args:
-            token (str): The JWT token string.
-        Returns:
-            Optional[str]: The audience claim if present, otherwise None.
-        """
-        if not token:
-            raise ValueError("Token must not be empty")
-        jwks: KeySet = await self._well_known_config_manager.get_jwks_async()
-        try:
-            claims = jwt.decode(token, jwks, algorithms=self.algorithms).claims
-            return claims.get("aud") or claims.get(
-                "client_id"
-            )  # AWS Cognito does not have aud claim but has client_id
-        except Exception as e:
-            logger.exception(f"Failed to extract audience from token: {e}")
-            return None
-
-    async def get_issued_from_token_async(
-        self, token: str
-    ) -> Optional[datetime.datetime]:
-        """
-        Extracts the 'iat' (issued at) claim from the JWT token.
-        Args:
-            token (str): The JWT token string.
-        Returns:
-            Optional[datetime.datetime]: The issued at time as a datetime object if present, otherwise None.
-        """
-        if not token:
-            raise ValueError("Token must not be empty")
-        jwks: KeySet = await self._well_known_config_manager.get_jwks_async()
-        try:
-            claims = jwt.decode(token, jwks, algorithms=self.algorithms).claims
-            iat = claims.get("iat")
-            if iat:
-                return datetime.datetime.fromtimestamp(iat, tz=ZoneInfo("UTC"))
-            return None
-        except Exception as e:
-            logger.exception(f"Failed to extract created at from token: {e}")
-            return None
-
     async def is_token_valid_async(self, access_token: str) -> bool:
         """
         Checks if the provided access token is valid (not expired and properly signed).
